<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture du fichier.</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sailcut</source>
        <translation type="obsolete">Sailcut</translation>
    </message>
    <message>
        <source>Sail corners coordinates</source>
        <translation>Coordonnées des coins de la voile</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>amure</translation>
    </message>
    <message>
        <source>clew</source>
        <translation>écoute</translation>
    </message>
    <message>
        <source>head</source>
        <translation>tête</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>pic</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation>Largeurs mesurées IRC</translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Définition de la voile</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensions de la voile</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>mm</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Position du rond</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Longueur guindant</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Longueur bordure</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Longueur chute</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Longueur vergue</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Rond de la chute</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Rond de la vergue</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Rond du guindant</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Rond de la bordure</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Angle vergue / guindant</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Géométrie du gréement</translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Base J du triangle avant</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Hauteur du point d&apos;amure</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Distance étrave-point d&apos;amure </translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Grand-voile</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Foc</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Hauteur I du triangle avant</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Longueur du bateau</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Quête du mât / guidant</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>Tissus</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Largeur coutures</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Largeur tissu</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Coupe</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Coupe mître</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Coupe transversale</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Coupe twist</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Coupe horizontale</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Nbre de sections</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Nbre de fuseaux radiaux</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Coupe radiale</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Coupe verticale</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Forme de voile</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Creux en haut</translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Creux au milieu</translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Creux de bordure</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Angle de vrillage</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Ourlet chute</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Ourlet autres</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Ouverture</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">m²</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Surface de la voile</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Calculer</translation>
    </message>
    <message>
        <source>Sail ID </source>
        <translation>Identification de la voile</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Nombre de fuseaux guindant</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Angle de dièdre</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Aile</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Identifiant de la voile</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>m2</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Manuel de Sailcut CAD</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>to &amp;DXF</source>
        <translation>&amp;DXF</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>voile &amp;TXT</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>voile &amp;XML</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Enregistrer &amp;sous</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>&amp;Dimensions</translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>&amp;Moule</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>&amp;Renforts</translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>&amp;Gréement</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Vue</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>About Sailcut</source>
        <translation>A propos de Sailcut</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>A propos de &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut</source>
        <translation>A propos de &amp;Sailcut</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>table traçante &amp;Carlson</translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>vue rendu 3D</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation>vue fil de  fer</translation>
    </message>
    <message>
        <source>development</source>
        <translation>développement</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>nouvelle voile créée</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>E&amp;xport voile 3D</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Export &amp;développement</translation>
    </message>
    <message>
        <source>Sailcut &amp;Handbook</source>
        <translation>&amp;Manuel de Sailcut</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Ouvrir fichier &amp;récent</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>chargé &apos;%1&apos;</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>erreur de chargement &apos;%1&apos;</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>écrit &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Erreur lors de l&apos;impression des données</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>Erreur lors de l&apos;impression du développement</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Erreur lors de l&apos;impression du dessin</translation>
    </message>
    <message>
        <source>data</source>
        <translation>données</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>dessin</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">développement</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <source>Sailcut data sheet</source>
        <translation>Données Sailcut</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Type de voile</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Grand-voile</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Foc</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Type de coupe</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Coupe transverse</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Coupe horizontale</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Coupe radiale</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Coupe twist Foot</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Coupe verticale</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Coupe à mitre</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation>sections,    </translation>
    </message>
    <message>
        <source> head gores.</source>
        <translation type="obsolete">fuseaux de tête.</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation>Gréement</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Longueur du bateau</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Hauteur I du triangle avant</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Base J du triangle avant</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Position X de l&apos;amure</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Hauteur Y de l&apos;amure</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Dimensions de la voile</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Longueur guindant</translation>
    </message>
    <message>
        <source>Mast rake</source>
        <translation type="obsolete">Quête du mat</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Angle vergue / guindant</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Longueur vergue</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Longueur bordure</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Longueur chute</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Forme des bords</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Rond du guindant</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Rond de la vergue</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Rond de la chute</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Rond de la bordure</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Position du rond de guindant</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Position du rond de la gaffe</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Position du rond de chute</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Position du rond de bordure</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Réglage de la voile</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>Angle de vrillage</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Angle d&apos;ouverture</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Tissu, coutures et ourlets</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Largeur du tissu</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Largeur des coutures</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Largeur pour ourlet chute</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Largeur pour autres ourlets</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Moule de voile</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Forme guindant</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Creux</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Forme chute</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Profil supérieur</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Profil médian à h =</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Profil inférieur</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Quête du mât / guidant</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation>fuseaux de tête,</translation>
    </message>
    <message>
        <source> luff gore.</source>
        <translation type="obsolete">fuseau coté guindant.</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Aile</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation>fuseaux de guindant.</translation>
    </message>
    <message>
        <source>E&amp;xport &amp;development</source>
        <translation type="obsolete">E&amp;xport développement</translation>
    </message>
    <message>
        <source>to &amp;hand-plotting format</source>
        <translation type="obsolete">format coupe &amp;manuelle</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation>pour traçage &amp;manuel</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Répartition verticale</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Moule de voile</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation>Profil supérieur</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Profil médian</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Profil inférieur</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>&amp;définition de voile</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>&amp;voile 3D</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>&amp;Ajouter une voile</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Ouvrir</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Enregistrer &amp;sous</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Une erreur s&apos;est produite lors de l&apos;écriture du fichier</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation>Gréement</translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Ouvrir fichier &amp;récent</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Informations sur la voile</translation>
    </message>
    <message>
        <source>file</source>
        <translation>fichier</translation>
    </message>
    <message>
        <source>name</source>
        <translation>nom</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre a jour</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Recharger</translation>
    </message>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Une erreur s&apos;est produite lors de la lecture du fichier sélectionné.</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">OpenGL n&apos;est pas disponible sur cette machine.</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Paramètres d&apos;affichage</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>élévation</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>azimuth</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>Réinitialiser la vue</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Etiquettes</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zoom avant</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zoom arrière</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>deg</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Luff shape</source>
        <translation>Forme guindant</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Creux</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Forme chute</translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>erreur</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Une erreur s&apos;est produite à la lecture du fichier sélectionné.</translation>
    </message>
</context>
</TS>
